==> oggcodecs_src_0.63.7755.zip: oggdsf/src/lib/player/libDSPlayDotNET/CMMLCallbackProxy.cpp <==
//===========================================================================
//Copyright (C) 2004 Zentaro Kavanagh
//
//Redistribution and use in source and binary forms, with or without
//modification, are permitted provided that the following conditions
//are met:
//
//- Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//- Redistributions in binary form must reproduce the above copyright
//  notice, this list of conditions and the following disclaimer in the
//  documentation and/or other materials provided with the distribution.
//
//- Neither the name of Zentaro Kavanagh nor the names of contributors 
//  may be used to endorse or promote products derived from this software 
//  without specific prior written permission.
//
//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
//PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
//CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
//EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
//PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
//PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
//LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
//NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//===========================================================================
#include "StdAfx.h"
#include ".\cmmlcallbackproxy.h"
#using <mscorlib.dll>

CMMLCallbackProxy::CMMLCallbackProxy(void)
	:	mDNCMMLCallbacks(NULL)
{
}

CMMLCallbackProxy::~CMMLCallbackProxy(void)
{
}

bool CMMLCallbackProxy::setManagedDelegate(gcroot<IDNCMMLCallbacks*> inManagedCallbacks) {
	mDNCMMLCallbacks = inManagedCallbacks;

}
bool CMMLCallbackProxy::clipCallback(C_ClipTag* inClipTag) {
	if (mDNCMMLCallbacks != NULL) {
		gcroot<ClipTag*> locClip = new ClipTag(inClipTag->clone());
	
		return mDNCMMLCallbacks->clipCallback(locClip);
	} else {
		return false;
	}
}
bool CMMLCallbackProxy::headCallback(C_HeadTag* inHeadTag) {
	if (mDNCMMLCallbacks != NULL) {
		gcroot<HeadTag*> locHead = new HeadTag(inHeadTag->clone());
	
		return mDNCMMLCallbacks->headCallback(locHead);
	} else {
		return false;
	}

}

==> oggcodecs_src_0.69.8924.zip: oggdsf/src/lib/player/libDSPlayDotNET/CMMLCallbackProxy.cpp <==
//===========================================================================
//Copyright (C) 2004 Zentaro Kavanagh
//
//Copyright (C) 2004 Commonwealth Scientific and Industrial Research
// Orgainisation (CSIRO) Australia
//
//Redistribution and use in source and binary forms, with or without
//modification, are permitted provided that the following conditions
//are met:
//
//- Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//- Redistributions in binary form must reproduce the above copyright
//  notice, this list of conditions and the following disclaimer in the
//  documentation and/or other materials provided with the distribution.
//
//- Neither the name of Zentaro Kavanagh nor the names of contributors 
//  may be used to endorse or promote products derived from this software 
//  without specific prior written permission.
//
//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
//PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
//CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
//EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
//PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
//PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
//LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
//NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//===========================================================================
#include "stdafx.h"
#include ".\cmmlcallbackproxy.h"
#using <mscorlib.dll>

CMMLCallbackProxy::CMMLCallbackProxy(void)
	:	mDNCMMLCallbacks(NULL)
{
}

CMMLCallbackProxy::~CMMLCallbackProxy(void)
{
}

bool CMMLCallbackProxy::setManagedDelegate(gcroot<IDNCMMLCallbacks*> inManagedCallbacks) {
	mDNCMMLCallbacks = inManagedCallbacks;

}
bool CMMLCallbackProxy::clipCallback(C_ClipTag* inClipTag) {
	if (mDNCMMLCallbacks != NULL) {
		gcroot<ClipTag*> locClip = new ClipTag(inClipTag->clone(), true);
	
		return mDNCMMLCallbacks->clipCallback(locClip);
	} else {
		return false;
	}
}
bool CMMLCallbackProxy::headCallback(C_HeadTag* inHeadTag) {
	if (mDNCMMLCallbacks != NULL) {
		gcroot<HeadTag*> locHead = new HeadTag(inHeadTag->clone(), true);
	
		return mDNCMMLCallbacks->headCallback(locHead);
	} else {
		return false;
	}

}
